@@ -63,7 +63,7 @@ basta.default <- function(object, studyStart, studyEnd, minAge = 0,
         require(snowfall)
         sfInit(parallel = TRUE, cpus = ncpus)
         sfExport(list = c(bastaIntVars, ".Random.seed"))
-        sfSource("/Users/fernando/FERNANDO/PROJECTS/4.PACKAGES/BaSTA/workspace/developBasta/code/loadBaSTA.R")
+#        sfSource("/Users/fernando/FERNANDO/PROJECTS/4.PACKAGES/BaSTA/workspace/developBasta/code/loadBaSTA.R")
         sfLibrary("BaSTA", character.only = TRUE, warn.conflicts = FALSE)
         sfLibrary(msm, warn.conflicts = FALSE)
         bastaOut <- sfClusterApplyLB(1:nsim, .RunBastaMCMC, algObj, defTheta, 
